==> sirikata-0.0.4-mac.tar.gz: sirikata_mac/include/sirikata/proxyobject/SimulationFactory.hpp <==
/*  Sirikata Object Host -- Proxy Creation and Destruction manager
 *  SimulationFactory.hpp
 *
 *  Copyright (c) 2009, Daniel Reiter Horn
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_SIMULATION_FACTORY_
#define _SIRIKATA_SIMULATION_FACTORY_

#include <sirikata/proxyobject/Platform.hpp>
#include <sirikata/core/util/ListenerProvider.hpp>
#include <sirikata/proxyobject/TimeSteppedQueryableSimulation.hpp>

namespace Sirikata{

///Class to create graphics subsystems. FIXME: should this load a dll when a named factory is not found
class SIRIKATA_PROXYOBJECT_EXPORT SimulationFactory
    : public AutoSingleton<SimulationFactory>,
      public Factory4<TimeSteppedQueryableSimulation*,
                      Context*,
                      VWObjectPtr, // Object simulation is working within
                      const SpaceObjectReference&, // Presence the simulation is working within
                      const String&> //options string for the graphics system
{
public:
    static SimulationFactory&getSingleton();
    static void destroy();
};


}
#endif

==> sirikata-0.0.17-mac.tar.gz: sirikata_mac/include/sirikata/proxyobject/SimulationFactory.hpp <==
/*  Sirikata Object Host -- Proxy Creation and Destruction manager
 *  SimulationFactory.hpp
 *
 *  Copyright (c) 2009, Daniel Reiter Horn
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _SIRIKATA_SIMULATION_FACTORY_
#define _SIRIKATA_SIMULATION_FACTORY_

#include <sirikata/proxyobject/Platform.hpp>
#include <sirikata/proxyobject/Defs.hpp>
#include <sirikata/proxyobject/Simulation.hpp>
#include <sirikata/core/service/Context.hpp>
#include <sirikata/proxyobject/ConnectionEventListener.hpp>

namespace Sirikata{

// Note that we provide a ConnectionEventProvider because we're in
// libproxyobject so we can't just provide the ObjectHostContext, which would
// give access to the ObjectHost if it was needed. Ideally we wouldn't pass this
// parameter since some Simulations don't care about it.
class SIRIKATA_PROXYOBJECT_EXPORT SimulationFactory
    : public AutoSingleton<SimulationFactory>,
      public Factory5<Simulation*,
                      Context*,
                      ConnectionEventProvider*,
                      VWObjectPtr, // Object simulation is working within
                      const SpaceObjectReference&, // Presence the simulation is working within
                      const String&> //options string for the graphics system
{
public:
    static SimulationFactory&getSingleton();
    static void destroy();
};


}
#endif
